"""
Copyright 2021-2023 MICRORISC s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import os
import json
from logging import Logger

from influxdb import InfluxDBClient

from Setter.Logging import Logging


class InfluxDbConfig:
	"""
	InfluxDB config.

	Methods
	-------
	configure() -> None:
		Configure IQRF MQTT-InfluxDB bridge.
	"""

	__credentials_file = '/etc/iqrf-gateway-setter/influxdb-credentials.json'
	__logger: Logger = Logging.get_logger()

	@classmethod
	def configure_admin_password(cls, password: str) -> None:
		"""
		Configure InfluxDB.

		Parameters
		----------
		password: str
			Password for the admin user

		Returns
		-------
		None
		"""
		client: InfluxDBClient = InfluxDbConfig.create_client()
		if not os.path.exists(cls.__credentials_file):
			return
		with open(cls.__credentials_file, 'r+', encoding='UTF-8') as file:
			credentials = json.load(file)
			if credentials['password'] != 'iqrf':
				file.close()
				client.close()
				return
			credentials['password'] = password
			client.set_user_password(credentials['username'], password)
			file.seek(0)
			json.dump(credentials, file, indent='\t', separators=(',', ': '), sort_keys=True)
			file.truncate()
			file.close()
		client.close()

	@staticmethod
	def create_client() -> InfluxDBClient:
		"""
		Create a new InfluxDB client instance.

		Parameters
		----------
		None

		"""
		with open(InfluxDbConfig.__credentials_file, 'r', encoding='UTF-8') as file:
			credentials = json.load(file)
		return InfluxDBClient(
			host='localhost',
			port=8086,
			username=credentials['username'],
			password=credentials['password'],
		)
